@@ -40,6 +40,7 @@
 #include "errmsg.h"
 #include "hashtable.h"
 
+
 #define JSON_COUNT_NAME "!mmcount"
 #define SEVERITY_COUNT 8
 
@@ -258,7 +259,7 @@ getCounter(struct hashtable *ht, char *str) {
 }
 
 BEGINdoAction
-	msg_t *pMsg;
+	smsg_t *pMsg;
 	char *appname;
 	struct json_object *json = NULL;
 	es_str_t *estr = NULL;
@@ -267,7 +268,7 @@ BEGINdoAction
 	int *pCounter;
 	instanceData *const pData = pWrkrData->pData;
 CODESTARTdoAction
-	pMsg = (msg_t*) ppString[0];
+	pMsg = (smsg_t*) ppString[0];
 	appname = getAPPNAME(pMsg, LOCK_MUTEX);
 
 	pthread_mutex_lock(&pData->mut);
@@ -297,6 +298,9 @@ CODESTARTdoAction
 
 	/* key found, so get the value */
 	pszValue = (char*)json_object_get_string(keyjson);
+	if(pszValue == NULL) { /* json null object returns NULL! */
+		pszValue = "";
+	}
 
 	if(pData->pszValue) {
 		/* value also given for count */
