@@ -232,7 +232,9 @@ enum cnffuncid {
 	CNFFUNC_REPLACE,
 	CNFFUNC_WRAP,
 	CNFFUNC_RANDOM,
-	CNFFUNC_DYN_INC
+	CNFFUNC_DYN_INC,
+	CNFFUNC_IPV42NUM,
+	CNFFUNC_NUM2IPV4
 };
 
 struct cnffunc {
