@@ -132,18 +132,26 @@ struct msg {
 };
 
 
-/* message flags (msgFlags), not an enum for historical reasons
- */
-#define NOFLAG		0x000	/* no flag is set (to be used when a flag must be specified and none is required) */
-#define INTERNAL_MSG	0x001	/* msg generated by logmsgInternal() --> special handling */
+/* message flags (msgFlags), not an enum for historical reasons */
+#define NOFLAG		0x000
+/* no flag is set (to be used when a flag must be specified and none is required) */
+#define INTERNAL_MSG	0x001
+/* msg generated by logmsgInternal() --> special handling */
 /* 0x002 not used because it was previously a known value - rgerhards, 2008-10-09 */
-#define IGNDATE		0x004	/* ignore, if given, date in message and use date of reception as msg date */
-#define MARK		0x008	/* this message is a mark */
-#define NEEDS_PARSING	0x010	/* raw message, must be parsed before processing can be done */
-#define PARSE_HOSTNAME	0x020	/* parse the hostname during message parsing */
-#define NEEDS_DNSRESOL	0x040	/* fromhost address is unresolved and must be locked up via DNS reverse lookup first */
-#define NEEDS_ACLCHK_U	0x080	/* check UDP ACLs after DNS resolution has been done in main queue consumer */
-#define NO_PRI_IN_RAW	0x100	/* rawmsg does not include a PRI (Solaris!), but PRI is already set correctly in the msg object */
+#define IGNDATE		0x004
+/* ignore, if given, date in message and use date of reception as msg date */
+#define MARK		0x008
+/* this message is a mark */
+#define NEEDS_PARSING	0x010
+/* raw message, must be parsed before processing can be done */
+#define PARSE_HOSTNAME	0x020
+/* parse the hostname during message parsing */
+#define NEEDS_DNSRESOL	0x040
+/* fromhost address is unresolved and must be locked up via DNS reverse lookup first */
+#define NEEDS_ACLCHK_U	0x080
+/* check UDP ACLs after DNS resolution has been done in main queue consumer */
+#define NO_PRI_IN_RAW	0x100
+/* rawmsg does not include a PRI (Solaris!), but PRI is already set correctly in the msg object */
 
 /* (syslog) protocol types */
 #define MSG_LEGACY_PROTOCOL 0
@@ -154,75 +162,77 @@ struct msg {
 /* function prototypes
  */
 PROTOTYPEObjClassInit(msg);
-rsRetVal msgConstruct(msg_t **ppThis);
-rsRetVal msgConstructWithTime(msg_t **ppThis, struct syslogTime *stTime, time_t ttGenTime);
-rsRetVal msgConstructForDeserializer(msg_t **ppThis);
-rsRetVal msgConstructFinalizer(msg_t *pThis);
-rsRetVal msgDestruct(msg_t **ppM);
-msg_t* MsgDup(msg_t* pOld);
-msg_t *MsgAddRef(msg_t *pM);
-void setProtocolVersion(msg_t *pM, int iNewVersion);
-void MsgSetInputName(msg_t *pMsg, prop_t*);
-void MsgSetDfltTZ(msg_t *pThis, char *tz);
-rsRetVal MsgSetAPPNAME(msg_t *pMsg, const char* pszAPPNAME);
-rsRetVal MsgSetPROCID(msg_t *pMsg, const char* pszPROCID);
-rsRetVal MsgSetMSGID(msg_t *pMsg, const char* pszMSGID);
-void MsgSetParseSuccess(msg_t *pMsg, int bSuccess);
-void MsgSetTAG(msg_t *pMsg, const uchar* pszBuf, const size_t lenBuf);
-void MsgSetRuleset(msg_t *pMsg, ruleset_t*);
-rsRetVal MsgSetFlowControlType(msg_t *pMsg, flowControl_t eFlowCtl);
-rsRetVal MsgSetStructuredData(msg_t *const pMsg, const char* pszStrucData);
-rsRetVal MsgAddToStructuredData(msg_t *pMsg, uchar *toadd, rs_size_t len);
-void MsgGetStructuredData(msg_t *pM, uchar **pBuf, rs_size_t *len);
-rsRetVal msgSetFromSockinfo(msg_t *pThis, struct sockaddr_storage *sa);
-void MsgSetRcvFrom(msg_t *pMsg, prop_t*);
-void MsgSetRcvFromStr(msg_t *const pMsg, const uchar* pszRcvFrom, const int, prop_t **);
-rsRetVal MsgSetRcvFromIP(msg_t *pMsg, prop_t*);
-rsRetVal MsgSetRcvFromIPStr(msg_t *const pThis, const uchar *psz, const int len, prop_t **ppProp);
-void MsgSetHOSTNAME(msg_t *pMsg, const uchar* pszHOSTNAME, const int lenHOSTNAME);
-rsRetVal MsgSetAfterPRIOffs(msg_t *pMsg, short offs);
-void MsgSetMSGoffs(msg_t *pMsg, short offs);
-void MsgSetRawMsgWOSize(msg_t *pMsg, char* pszRawMsg);
-void MsgSetRawMsg(msg_t *pMsg, const char* pszRawMsg, size_t lenMsg);
-rsRetVal MsgReplaceMSG(msg_t *pThis, const uchar* pszMSG, int lenMSG);
-uchar *MsgGetProp(msg_t *pMsg, struct templateEntry *pTpe, msgPropDescr_t *pProp,
+rsRetVal msgConstruct(smsg_t **ppThis);
+rsRetVal msgConstructWithTime(smsg_t **ppThis, struct syslogTime *stTime, time_t ttGenTime);
+rsRetVal msgConstructForDeserializer(smsg_t **ppThis);
+rsRetVal msgConstructFinalizer(smsg_t *pThis);
+rsRetVal msgDestruct(smsg_t **ppM);
+smsg_t * MsgDup(smsg_t * pOld);
+smsg_t *MsgAddRef(smsg_t *pM);
+void setProtocolVersion(smsg_t *pM, int iNewVersion);
+void MsgSetInputName(smsg_t *pMsg, prop_t*);
+void MsgSetDfltTZ(smsg_t *pThis, char *tz);
+rsRetVal MsgSetAPPNAME(smsg_t *pMsg, const char* pszAPPNAME);
+rsRetVal MsgSetPROCID(smsg_t *pMsg, const char* pszPROCID);
+rsRetVal MsgSetMSGID(smsg_t *pMsg, const char* pszMSGID);
+void MsgSetParseSuccess(smsg_t *pMsg, int bSuccess);
+void MsgSetTAG(smsg_t *pMsg, const uchar* pszBuf, const size_t lenBuf);
+void MsgSetRuleset(smsg_t *pMsg, ruleset_t*);
+rsRetVal MsgSetFlowControlType(smsg_t *pMsg, flowControl_t eFlowCtl);
+rsRetVal MsgSetStructuredData(smsg_t *const pMsg, const char* pszStrucData);
+rsRetVal MsgAddToStructuredData(smsg_t *pMsg, uchar *toadd, rs_size_t len);
+void MsgGetStructuredData(smsg_t *pM, uchar **pBuf, rs_size_t *len);
+rsRetVal msgSetFromSockinfo(smsg_t *pThis, struct sockaddr_storage *sa);
+void MsgSetRcvFrom(smsg_t *pMsg, prop_t*);
+void MsgSetRcvFromStr(smsg_t *const pMsg, const uchar* pszRcvFrom, const int, prop_t **);
+rsRetVal MsgSetRcvFromIP(smsg_t *pMsg, prop_t*);
+rsRetVal MsgSetRcvFromIPStr(smsg_t *const pThis, const uchar *psz, const int len, prop_t **ppProp);
+void MsgSetHOSTNAME(smsg_t *pMsg, const uchar* pszHOSTNAME, const int lenHOSTNAME);
+rsRetVal MsgSetAfterPRIOffs(smsg_t *pMsg, short offs);
+void MsgSetMSGoffs(smsg_t *pMsg, short offs);
+void MsgSetRawMsgWOSize(smsg_t *pMsg, char* pszRawMsg);
+void MsgSetRawMsg(smsg_t *pMsg, const char* pszRawMsg, size_t lenMsg);
+rsRetVal MsgReplaceMSG(smsg_t *pThis, const uchar* pszMSG, int lenMSG);
+uchar *MsgGetProp(smsg_t *pMsg, struct templateEntry *pTpe, msgPropDescr_t *pProp,
 		  rs_size_t *pPropLen, unsigned short *pbMustBeFreed, struct syslogTime *ttNow);
-uchar *getRcvFrom(msg_t *pM);
-void getTAG(msg_t *pM, uchar **ppBuf, int *piLen);
-const char *getTimeReported(msg_t *pM, enum tplFormatTypes eFmt);
-const char *getPRI(msg_t *pMsg);
-int getPRIi(const msg_t * const pM);
-void getRawMsg(msg_t *pM, uchar **pBuf, int *piLen);
-rsRetVal msgAddJSON(msg_t *pM, uchar *name, struct json_object *json, int force_reset, int sharedReference);
-rsRetVal msgAddMetadata(msg_t *msg, uchar *metaname, uchar *metaval);
-rsRetVal MsgGetSeverity(msg_t *pThis, int *piSeverity);
-rsRetVal MsgDeserialize(msg_t *pMsg, strm_t *pStrm);
-rsRetVal MsgSetPropsViaJSON(msg_t *__restrict__ const pMsg, const uchar *__restrict__ const json);
-const uchar* msgGetJSONMESG(msg_t *__restrict__ const pMsg);
+uchar *getRcvFrom(smsg_t *pM);
+void getTAG(smsg_t *pM, uchar **ppBuf, int *piLen);
+const char *getTimeReported(smsg_t *pM, enum tplFormatTypes eFmt);
+const char *getPRI(smsg_t *pMsg);
+int getPRIi(const smsg_t * const pM);
+void getRawMsg(smsg_t *pM, uchar **pBuf, int *piLen);
+rsRetVal msgAddJSON(smsg_t *pM, uchar *name, struct json_object *json, int force_reset, int sharedReference);
+rsRetVal msgAddMetadata(smsg_t *msg, uchar *metaname, uchar *metaval);
+rsRetVal MsgGetSeverity(smsg_t *pThis, int *piSeverity);
+rsRetVal MsgDeserialize(smsg_t *pMsg, strm_t *pStrm);
+rsRetVal MsgSetPropsViaJSON(smsg_t *__restrict__ const pMsg, const uchar *__restrict__ const json);
+const uchar* msgGetJSONMESG(smsg_t *__restrict__ const pMsg);
 
 /* TODO: remove these five (so far used in action.c) */
-uchar *getMSG(msg_t *pM);
-const char *getHOSTNAME(msg_t *pM);
-char *getPROCID(msg_t *pM, sbool bLockMutex);
-char *getAPPNAME(msg_t *pM, sbool bLockMutex);
-void setMSGLen(msg_t *pM, int lenMsg);
-int getMSGLen(msg_t *pM);
+uchar *getMSG(smsg_t *pM);
+const char *getHOSTNAME(smsg_t *pM);
+char *getPROCID(smsg_t *pM, sbool bLockMutex);
+char *getAPPNAME(smsg_t *pM, sbool bLockMutex);
+void setMSGLen(smsg_t *pM, int lenMsg);
+int getMSGLen(smsg_t *pM);
 
-int getHOSTNAMELen(msg_t *pM);
-uchar *getProgramName(msg_t *pM, sbool bLockMutex);
-uchar *getRcvFrom(msg_t *pM);
+int getHOSTNAMELen(smsg_t *pM);
+uchar *getProgramName(smsg_t *pM, sbool bLockMutex);
+uchar *getRcvFrom(smsg_t *pM);
 rsRetVal propNameToID(uchar *pName, propid_t *pPropID);
 uchar *propIDToName(propid_t propID);
-rsRetVal msgGetJSONPropJSON(msg_t *pMsg, msgPropDescr_t *pProp, struct json_object **pjson);
-rsRetVal msgGetJSONPropJSONorString(msg_t * const pMsg, msgPropDescr_t *pProp, struct json_object **pjson, uchar **pcstr);
-rsRetVal getJSONPropVal(msg_t *pMsg, msgPropDescr_t *pProp, uchar **pRes, rs_size_t *buflen, unsigned short *pbMustBeFreed);
-rsRetVal msgSetJSONFromVar(msg_t *pMsg, uchar *varname, struct var *var, int force_reset);
-rsRetVal msgDelJSON(msg_t *pMsg, uchar *varname);
+rsRetVal msgGetJSONPropJSON(smsg_t *pMsg, msgPropDescr_t *pProp, struct json_object **pjson);
+rsRetVal msgGetJSONPropJSONorString(smsg_t * const pMsg, msgPropDescr_t *pProp, struct json_object **pjson,
+uchar **pcstr);
+rsRetVal getJSONPropVal(smsg_t *pMsg, msgPropDescr_t *pProp, uchar **pRes, rs_size_t *buflen,
+unsigned short *pbMustBeFreed);
+rsRetVal msgSetJSONFromVar(smsg_t *pMsg, uchar *varname, struct svar *var, int force_reset);
+rsRetVal msgDelJSON(smsg_t *pMsg, uchar *varname);
 rsRetVal jsonFind(struct json_object *jroot, msgPropDescr_t *pProp, struct json_object **jsonres);
 
 rsRetVal msgPropDescrFill(msgPropDescr_t *pProp, uchar *name, int nameLen);
 void msgPropDescrDestruct(msgPropDescr_t *pProp);
-void msgSetPRI(msg_t *const __restrict__ pMsg, syslog_pri_t pri);
+void msgSetPRI(smsg_t *const __restrict__ pMsg, syslog_pri_t pri);
 
 #define msgGetProtocolVersion(pM) ((pM)->iProtocolVersion)
 
@@ -244,7 +254,7 @@ void msgSetPRI(msg_t *const __restrict__ pMsg, syslog_pri_t pri);
  * rgerhards, 2009-08-26
  */
 static inline void __attribute__((unused))
-MsgSetRawMsgSize(msg_t *const __restrict__ pMsg, const size_t newLen)
+MsgSetRawMsgSize(smsg_t *const __restrict__ pMsg, const size_t newLen)
 {
 	assert(newLen <= (size_t) pMsg->iLenRawMsg);
 	pMsg->iLenRawMsg = newLen;
