@@ -64,7 +64,7 @@ static struct hashtable *stats_senders = NULL;
 
 /* ------------------------------ statsobj linked list maintenance  ------------------------------ */
 
-static inline void
+static void
 addToObjList(statsobj_t *pThis)
 {
 	pthread_mutex_lock(&mutStats);
@@ -88,7 +88,7 @@ addToObjList(statsobj_t *pThis)
 }
 
 
-static inline void
+static void
 removeFromObjList(statsobj_t *pThis)
 {
 	pthread_mutex_lock(&mutStats);
@@ -104,7 +104,7 @@ removeFromObjList(statsobj_t *pThis)
 }
 
 
-static inline void
+static void
 addCtrToList(statsobj_t *pThis, ctr_t *pCtr)
 {
 	pthread_mutex_lock(&pThis->mutCtr);
@@ -202,7 +202,8 @@ finalize_it:
  * is called.
  */
 static rsRetVal
-addManagedCounter(statsobj_t *pThis, const uchar *ctrName, statsCtrType_t ctrType, int8_t flags, void *pCtr, ctr_t **entryRef, int8_t linked)
+addManagedCounter(statsobj_t *pThis, const uchar *ctrName, statsCtrType_t ctrType, int8_t flags, void *pCtr,
+ctr_t **entryRef, int8_t linked)
 {
 	ctr_t *ctr;
 	DEFiRet;
@@ -241,7 +242,7 @@ finalize_it:
 	RETiRet;
 }
 
-static inline void
+static void
 addPreCreatedCounter(statsobj_t *pThis, ctr_t *pCtr)
 {
 	pCtr->next = NULL;
@@ -285,7 +286,7 @@ destructCounter(statsobj_t *pThis, ctr_t *pCtr)
 	destructUnlinkedCounter(pCtr);
 }
 
-static inline void
+static void
 resetResettableCtr(ctr_t *pCtr, int8_t bResetCtrs)
 {
 	if ((bResetCtrs && (pCtr->flags & CTR_FLAG_RESETTABLE)) ||
@@ -593,7 +594,8 @@ statsRecordSender(const uchar *sender, unsigned nMsgs, time_t lastSeen)
 
 	stat->nMsgs += nMsgs;
 	stat->lastSeen = lastSeen;
-	DBGPRINTF("DDDDD: statsRecordSender: '%s', nmsgs %u [%llu], lastSeen %llu\n", sender, nMsgs, (long long unsigned) stat->nMsgs, (long long unsigned) lastSeen);
+	DBGPRINTF("DDDDD: statsRecordSender: '%s', nmsgs %u [%llu], lastSeen %llu\n", sender, nMsgs,
+	(long long unsigned) stat->nMsgs, (long long unsigned) lastSeen);
 
 finalize_it:
 	if(mustUnlock)
