@@ -1,11 +1,5 @@
 #!/bin/bash
 # add 2017-04-28 by Pascal Withopf, released under ASL 2.0
-uname
-if [ `uname` = "SunOS" ] ; then
-   echo "Solaris: inotify isn't supported on Solaris"
-   exit 77
-fi
-
 . $srcdir/diag.sh init
 . $srcdir/diag.sh generate-conf
 . $srcdir/diag.sh add-conf '
