@@ -7,12 +7,6 @@
 # is because it is not so easy to pick it up from the system log and other
 # tests already cover this szenario.
 # add 2017-05-10 by Rainer Gerhards, released under ASL 2.0
-uname
-if [ `uname` = "SunOS" ] ; then # TODO: do we really need this test?
-   echo "Solaris: inotify isn't supported on Solaris"
-   exit 77
-fi
-
 . $srcdir/diag.sh init
 . $srcdir/diag.sh generate-conf
 . $srcdir/diag.sh add-conf '
