@@ -1,6 +1,13 @@
 #!/bin/bash
 # test many concurrent tcp connections
 echo \[manytcp.sh\]: test concurrent tcp connections
+
+uname
+if [ `uname` = "SunOS" ] ; then
+   echo "Solaris: FIX ME"
+   exit 77
+fi
+
 . $srcdir/diag.sh init
 . $srcdir/diag.sh startup manytcp.conf
 # the config file specifies exactly 1100 connections
