@@ -214,6 +214,11 @@ static void* thrdStarter(void *arg)
 	sigaddset(&sigSet, SIGTTIN);
 	pthread_sigmask(SIG_UNBLOCK, &sigSet, NULL);
 
+	/* AIXPORT unblock SIGSEGV so that the process core dumps on segmentation fault */
+	sigemptyset(&sigSet);
+	sigaddset(&sigSet, SIGSEGV);
+	pthread_sigmask(SIG_UNBLOCK, &sigSet, NULL);
+	/* AIXPORT */
 	/* setup complete, we are now ready to execute the user code. We will not
 	 * regain control until the user code is finished, in which case we terminate
 	 * the thread.
@@ -239,10 +244,14 @@ static void* thrdStarter(void *arg)
  * executing threads. It is added at the end of the list.
  * rgerhards, 2007-12-14
  */
-rsRetVal thrdCreate(rsRetVal (*thrdMain)(thrdInfo_t*), rsRetVal(*afterRun)(thrdInfo_t *), sbool bNeedsCancel, uchar *name)
+rsRetVal thrdCreate(rsRetVal (*thrdMain)(thrdInfo_t*), rsRetVal(*afterRun)(thrdInfo_t *),
+	sbool bNeedsCancel, uchar *name)
 {
 	DEFiRet;
 	thrdInfo_t *pThis;
+#if defined (_AIX)
+	pthread_attr_t aix_attr;
+#endif
 
 	assert(thrdMain != NULL);
 
@@ -252,7 +261,13 @@ rsRetVal thrdCreate(rsRetVal (*thrdMain)(thrdInfo_t*), rsRetVal(*afterRun)(thrdI
 	pThis->pAfterRun = afterRun;
 	pThis->bNeedsCancel = bNeedsCancel;
 	pThis->name = ustrdup(name);
+#if defined (_AIX)
+        pthread_attr_init(&aix_attr);
+        pthread_attr_setstacksize(&aix_attr, 4096*512);
+        pthread_create(&pThis->thrdID, &aix_attr, thrdStarter, pThis);
+#else
 	pthread_create(&pThis->thrdID, &default_thread_attr, thrdStarter, pThis);
+#endif
 	CHKiRet(llAppend(&llThrds, NULL, pThis));
 
 finalize_it:
