@@ -42,7 +42,8 @@
 #include "parser.h"
 #include "datetime.h"
 #include "unicode-helper.h"
-
+#ifdef _AIX
+#endif
 MODULE_TYPE_PARSER
 MODULE_TYPE_NOKEEP
 PARSER_NAME("rsyslog.rfc3164")
@@ -65,7 +66,10 @@ static int bParseHOSTNAMEandTAG;	/* cache for the equally-named global param - p
 static struct cnfparamdescr parserpdescr[] = {
 	{ "detect.yearaftertimestamp", eCmdHdlrBinary, 0 },
 	{ "permit.squarebracketsinhostname", eCmdHdlrBinary, 0 },
-	{ "permit.slashesinhostname", eCmdHdlrBinary, 0 }
+	{ "permit.slashesinhostname", eCmdHdlrBinary, 0 },
+	{ "permit.atsignsinhostname", eCmdHdlrBinary, 0 },
+	{ "force.tagendingbycolon", eCmdHdlrBinary, 0},
+	{ "remove.msgfirstspace", eCmdHdlrBinary, 0},
 };
 static struct cnfparamblk parserpblk =
 	{ CNFPARAMBLK_VERSION,
@@ -77,6 +81,9 @@ struct instanceConf_s {
 	int bDetectYearAfterTimestamp;
 	int bPermitSquareBracketsInHostname;
 	int bPermitSlashesInHostname;
+	int bPermitAtSignsInHostname;
+	int bForceTagEndingByColon;
+	int bRemoveMsgFirstSpace;
 };
 
 
@@ -101,6 +108,10 @@ createInstance(instanceConf_t **pinst)
 	inst->bDetectYearAfterTimestamp = 0;
 	inst->bPermitSquareBracketsInHostname = 0;
 	inst->bPermitSlashesInHostname = 0;
+	inst->bPermitAtSignsInHostname = 0;
+	inst->bForceTagEndingByColon = 0;
+	inst->bRemoveMsgFirstSpace = 0;
+	bParseHOSTNAMEandTAG=glbl.GetParseHOSTNAMEandTAG();
 	*pinst = inst;
 finalize_it:
 	RETiRet;
@@ -136,6 +147,12 @@ CODESTARTnewParserInst
 			inst->bPermitSquareBracketsInHostname = (int) pvals[i].val.d.n;
 		} else if(!strcmp(parserpblk.descr[i].name, "permit.slashesinhostname")) {
 			inst->bPermitSlashesInHostname = (int) pvals[i].val.d.n;
+		} else if(!strcmp(parserpblk.descr[i].name, "permit.atsignsinhostname")) {
+			inst->bPermitAtSignsInHostname = (int) pvals[i].val.d.n;
+		} else if(!strcmp(parserpblk.descr[i].name, "force.tagendingbycolon")) {
+			inst->bForceTagEndingByColon = (int) pvals[i].val.d.n;
+		} else if(!strcmp(parserpblk.descr[i].name, "remove.msgfirstspace")) {
+			inst->bRemoveMsgFirstSpace = (int) pvals[i].val.d.n;
 		} else {
 			dbgprintf("pmrfc3164: program error, non-handled "
 			  "param '%s'\n", parserpblk.descr[i].name);
@@ -168,7 +185,8 @@ CODESTARTparse
 	DBGPRINTF("Message will now be parsed by the legacy syslog parser (one size fits all... ;)).\n");
 	assert(pMsg != NULL);
 	assert(pMsg->pszRawMsg != NULL);
-	lenMsg = pMsg->iLenRawMsg - pMsg->offAfterPRI; /* note: offAfterPRI is already the number of PRI chars (do not add one!) */
+	lenMsg = pMsg->iLenRawMsg - pMsg->offAfterPRI;
+	/* note: offAfterPRI is already the number of PRI chars (do not add one!) */
 	p2parse = pMsg->pszRawMsg + pMsg->offAfterPRI; /* point to start of text, after PRI */
 	setProtocolVersion(pMsg, MSG_LEGACY_PROTOCOL);
 	if(pMsg->iFacility == (LOG_INVLD>>3))
@@ -183,14 +201,17 @@ CODESTARTparse
 	 */
 	if(datetime.ParseTIMESTAMP3339(&(pMsg->tTIMESTAMP), &p2parse, &lenMsg) == RS_RET_OK) {
 		/* we are done - parse pointer is moved by ParseTIMESTAMP3339 */;
-	} else if(datetime.ParseTIMESTAMP3164(&(pMsg->tTIMESTAMP), &p2parse, &lenMsg, NO_PARSE3164_TZSTRING, pInst->bDetectYearAfterTimestamp) == RS_RET_OK) {
+	} else if(datetime.ParseTIMESTAMP3164(&(pMsg->tTIMESTAMP), &p2parse, &lenMsg, NO_PARSE3164_TZSTRING,
+	pInst->bDetectYearAfterTimestamp) == RS_RET_OK) {
 		if(pMsg->dfltTZ[0] != '\0')
 			applyDfltTZ(&pMsg->tTIMESTAMP, pMsg->dfltTZ);
 		/* we are done - parse pointer is moved by ParseTIMESTAMP3164 */;
-	} else if(*p2parse == ' ' && lenMsg > 1) { /* try to see if it is slighly malformed - HP procurve seems to do that sometimes */
+	} else if(*p2parse == ' ' && lenMsg > 1) {
+	/* try to see if it is slighly malformed - HP procurve seems to do that sometimes */
 		++p2parse;	/* move over space */
 		--lenMsg;
-		if(datetime.ParseTIMESTAMP3164(&(pMsg->tTIMESTAMP), &p2parse, &lenMsg, NO_PARSE3164_TZSTRING, pInst->bDetectYearAfterTimestamp) == RS_RET_OK) {
+		if(datetime.ParseTIMESTAMP3164(&(pMsg->tTIMESTAMP), &p2parse, &lenMsg, NO_PARSE3164_TZSTRING,
+		pInst->bDetectYearAfterTimestamp) == RS_RET_OK) {
 			/* indeed, we got it! */
 			/* we are done - parse pointer is moved by ParseTIMESTAMP3164 */;
 		} else {/* parse pointer needs to be restored, as we moved it off-by-one
@@ -245,6 +266,7 @@ CODESTARTparse
 			        && (isalnum(p2parse[i]) || p2parse[i] == '.'
 					|| p2parse[i] == '_' || p2parse[i] == '-'
 					|| (p2parse[i] == ']' && bHadSBracket)
+					|| (p2parse[i] == '@' && pInst->bPermitAtSignsInHostname)
 					|| (p2parse[i] == '/' && pInst->bPermitSlashesInHostname) )
 				&& i < (CONF_HOSTNAME_MAXSIZE - 1)) {
 				bufParseHOSTNAME[i] = p2parse[i];
@@ -312,6 +334,17 @@ CODESTARTparse
 			--lenMsg;
 			bufParseTAG[i++] = ':';
 		}
+		else if (pInst->bForceTagEndingByColon) {
+			/* Tag need to be ended by a colon or it's not a tag but the
+			 * begin of the message
+			 */
+			p2parse -= ( i + 1 );
+			lenMsg += ( i + 1 );
+			i = 0;
+			/* Default TAG is dash (without ':')
+			 */
+			bufParseTAG[i++] = '-';
+		}
 
 		/* no TAG can only be detected if the message immediatly ends, in which case an empty TAG
 		 * is considered OK. So we do not need to check for empty TAG. -- rgerhards, 2009-06-23
@@ -327,6 +360,12 @@ CODESTARTparse
 	}
 
 finalize_it:
+	if (pInst->bRemoveMsgFirstSpace && *p2parse == ' ') {
+		/* Bypass first space found in MSG part
+		 */
+	        p2parse++;
+	        lenMsg--;
+	}
 	MsgSetMSGoffs(pMsg, p2parse - pMsg->pszRawMsg);
 ENDparse2
 
@@ -350,7 +389,8 @@ ENDqueryEtryPt
 
 BEGINmodInit(pmrfc3164)
 CODESTARTmodInit
-	*ipIFVersProvided = CURR_MOD_IF_VERSION; /* we only support the current interface specification */
+	*ipIFVersProvided = CURR_MOD_IF_VERSION;
+	/* we only support the current interface specification */
 CODEmodInit_QueryRegCFSLineHdlr
 	CHKiRet(objUse(glbl, CORE_COMPONENT));
 	CHKiRet(objUse(errmsg, CORE_COMPONENT));
@@ -358,7 +398,8 @@ CODEmodInit_QueryRegCFSLineHdlr
 	CHKiRet(objUse(datetime, CORE_COMPONENT));
 
 	DBGPRINTF("rfc3164 parser init called\n");
- 	bParseHOSTNAMEandTAG = glbl.GetParseHOSTNAMEandTAG(); /* cache value, is set only during rsyslogd option processing */
+ 	bParseHOSTNAMEandTAG = glbl.GetParseHOSTNAMEandTAG();
+	/* cache value, is set only during rsyslogd option processing */
 
 
 ENDmodInit
